@@ -38,7 +38,7 @@ drive_mime_type <- function(type = NULL) {
     return(.drive$mime_tbl)
   }
   if (!(is.character(type))) {
-    stop_glue("'type' must be character")
+    drive_abort("{.arg type} must be character.")
   }
 
   human_m <- match(
@@ -57,10 +57,10 @@ drive_mime_type <- function(type = NULL) {
   mime_type <- .drive$mime_tbl$mime_type[m]
 
   if (all(is.na(mime_type))) {
-    stop_glue(
-      "\nUnrecognized 'type':\n  * {problems}",
-      problems = glue_collapse(type[is.na(mime_type)], sep = "\n")
-    )
+    drive_abort(c(
+      "Unrecognized {.arg type}:",
+      bulletize(gargle_map_cli(type), bullet = "x")
+    ))
   }
   mime_type
 }
@@ -91,7 +91,7 @@ drive_extension <- function(type = NULL) {
   stopifnot(is.character(type))
 
   type <- drive_mime_type(type)
-  m <- purrr::map_int(type, one_ext)
+  m <- map_int(type, one_ext)
   .drive$mime_tbl$ext[m]
 }
 
@@ -103,13 +103,3 @@ one_ext <- function(type) {
   }
   m
 }
-
-drive_reveal_mime_type <- function(file) {
-  confirm_dribble(file)
-  if (no_file(file)) {
-    return(
-      put_column(dribble(), nm = "mime_type", val = character(), .after = "name")
-    )
-  }
-  promote(file, "mime_type")
-}
